require 'minitest_helper'

describe CsvLineSerialize::Serializer do
  describe '#execute' do
    describe 'regular input' do
      before do
        csv_line = '111,222,333'
        @Serializer = CsvLineSerialize::Serializer.new(csv_line)
      end

      it 'serialized' do
        assert @Serializer.execute == "111\n222\n333"
      end
    end

    describe 'has comma at end of line' do
      before do
        csv_line = '111,222,333,'
        @Serializer = CsvLineSerialize::Serializer.new(csv_line)
      end

      it 'removed' do
        assert @Serializer.execute == "111\n222\n333"
      end
    end

    describe 'has comma at start of line' do
      before do
        csv_line = ',111,222,333'
        @Serializer = CsvLineSerialize::Serializer.new(csv_line)
      end

      it 'removed' do
        assert @Serializer.execute == "111\n222\n333"
      end
    end

    describe 'not string argument' do
      before do
        csv_line = 333
        @Serializer = CsvLineSerialize::Serializer.new(csv_line)
      end

      it 'to_s' do
        assert @Serializer.execute == "333"
      end
    end

    describe 'frozen string' do
      before do
        csv_line = "111,222,333".freeze
        @Serializer = CsvLineSerialize::Serializer.new(csv_line)
      end

      it 'can use' do
        assert @Serializer.execute == "111\n222\n333"
      end
    end
  end
end